;; Generated package description from el-job.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "el-job" "2.7.4.0.20260306.64315" "Contrived way to call a function using all CPU cores" '((emacs "29.1")) :commit "8b21c8f9a47a71102bf4ec08504b044aeab880fe" :authors '(("Martin Edström" . "meedstrom@runbox.eu")) :maintainer '("Martin Edström" . "meedstrom@runbox.eu") :keywords '("processes") :url "https://github.com/meedstrom/el-job")
